@@ -31,7 +31,7 @@ public:
 	static void Destroy(b2Contact* contact, b2BlockAllocator* allocator);
 
 	b2EdgeAndPolygonContact(b2Fixture* fixtureA, b2Fixture* fixtureB);
-	~b2EdgeAndPolygonContact() {}
+	~b2EdgeAndPolygonContact() override {}
 
 	void Evaluate(b2Manifold* manifold, const b2Transform& xfA, const b2Transform& xfB) Q_DECL_OVERRIDE;
 };
