@@ -31,7 +31,7 @@ public:
 	static void Destroy(b2Contact* contact, b2BlockAllocator* allocator);
 
 	b2LoopAndCircleContact(b2Fixture* fixtureA, int32 indexA, b2Fixture* fixtureB, int32 indexB);
-	~b2LoopAndCircleContact() {}
+	~b2LoopAndCircleContact() override {}
 
 	void Evaluate(b2Manifold* manifold, const b2Transform& xfA, const b2Transform& xfB) Q_DECL_OVERRIDE;
 };
