@@ -196,7 +196,7 @@ void KolfWindow::setupActions()
 	soundAction->setChecked(configGroup.readEntry("sound", true));
 
 	aboutAction = actionCollection()->addAction(QStringLiteral("aboutcourse"));
-	aboutAction->setText(i18n("&About Course"));
+	aboutAction->setText(i18n("&About Course..."));
 	connect(aboutAction, &QAction::triggered, this, &KolfWindow::emptySlot);
 	tutorialAction = actionCollection()->addAction(QStringLiteral("tutorial"));
 	tutorialAction->setText(i18n("&Tutorial"));
@@ -290,9 +290,11 @@ void KolfWindow::startNewGame()
 	connect(game, &KolfGame::largestHole, this, &KolfWindow::updateHoleMenu);
 	connect(game, &KolfGame::titleChanged, this, &KolfWindow::titleChanged);
 	connect(game, &KolfGame::newStatusText, this, &KolfWindow::newStatusText);
-	connect(game, QOverload<int>::of(&KolfGame::currentHole), this, &KolfWindow::setCurrentHole);
-	connect(holeAction, &QAction::triggered, game, QOverload<int>::of(&KolfGame::switchHole));
-	connect(nextAction, &QAction::triggered, game, &KolfGame::nextHole);
+        connect(game, qOverload<int>(&KolfGame::currentHole), this,
+                &KolfWindow::setCurrentHole);
+        connect(holeAction, &QAction::triggered, game,
+                qOverload<int>(&KolfGame::switchHole));
+        connect(nextAction, &QAction::triggered, game, &KolfGame::nextHole);
 	connect(prevAction, &QAction::triggered, game, &KolfGame::prevHole);
 	connect(firstAction, &QAction::triggered, game, &KolfGame::firstHole);
 	connect(lastAction, &QAction::triggered, game, &KolfGame::lastHole);
@@ -551,7 +553,7 @@ void KolfWindow::saveAs()
 	if (fileSaveDialog->exec() == QDialog::Accepted) {
 		QUrl newfile = fileSaveDialog->selectedUrls().first();
 		if (!newfile.isEmpty()) {
-			filename = newfile.url();
+			filename = newfile.toLocalFile();
 			game->setFilename(filename);
 			game->save();
 			game->setFocus();
@@ -572,7 +574,7 @@ void KolfWindow::saveGameAs()
 				return;
 			}
 			else {
-				loadedGame = newfile.url();
+				loadedGame = newfile.toLocalFile();
 				saveGame();
 			}
 		}
@@ -606,7 +608,7 @@ void KolfWindow::loadGame()
 	fileLoadDialog->setAcceptMode(QFileDialog::AcceptOpen);
 	fileLoadDialog->setFileMode(QFileDialog::ExistingFile);
 	if (fileLoadDialog->exec() == QDialog::Accepted) {
-		QUrl loadedGame = fileLoadDialog->selectedUrls().first();
+		loadedGame = fileLoadDialog->selectedUrls().first().toLocalFile();
 		if (loadedGame.isEmpty()) {
 			return;
 		}
